@@ -59,14 +59,14 @@ function h2i_info
 
 function h2i_error
 {
-	echo "$H2I: $@"; h2i_info; exit 1
+	echo "$H2I: $@" >&2; h2i_info >&2; exit 1
 }
 
 function h2i_check_and_echo
 {
 	if [[ $? == 0 ]]
 	then echo "done"
-	else echo "error"; h2i_cat "$1"; h2i_info; exit 1
+	else echo "error"; h2i_cat "$1" >&2; h2i_info >&2; exit 1
 	fi
 }
 
@@ -273,107 +273,107 @@ then
 	h2i_error "${H2I_INFO_PROGRAM_NAME}.texi: file exists"
 else
 	printf "Creating ${H2I_INFO_PROGRAM_NAME}.texi..."
-		cat 2>> "$H2I_ERROR_LOG" > "${H2I_INFO_PROGRAM_NAME}.texi" <<-EOF
-		\input texinfo	@c -*-texinfo-*-
-		@comment It was generated by $H2I $H2I_VERSION.
-		@comment %**start of header
-		@setfilename ${H2I_INFO_PROGRAM_NAME}.info
-		@include version.texi
-		@settitle $H2I_INFO_PROGRAM_NAME @value{VERSION}
-		@syncodeindex pg cp
-		@comment %**end of header
-		@copying
-		This manual is for $H2I_INFO_PROGRAM_NAME
-		(version @value{VERSION}, @value{UPDATED}),
-		which is a program that $H2I_INFO_DESCRIPTION
+		cat 2>> "$H2I_ERROR_LOG" > "${H2I_INFO_PROGRAM_NAME}.texi" <<EOF
+\input texinfo	@c -*-texinfo-*-
+@comment It was generated by $H2I $H2I_VERSION.
+@comment %**start of header
+@setfilename ${H2I_INFO_PROGRAM_NAME}.info
+@include version.texi
+@settitle $H2I_INFO_PROGRAM_NAME @value{VERSION}
+@syncodeindex pg cp
+@comment %**end of header
+@copying
+This manual is for $H2I_INFO_PROGRAM_NAME
+(version @value{VERSION}, @value{UPDATED}),
+which is a program that $H2I_INFO_DESCRIPTION
 
-		Copyright @copyright{} $H2I_INFO_YEAR $H2I_INFO_COPYRIGHT
+Copyright @copyright{} $H2I_INFO_YEAR $H2I_INFO_COPYRIGHT
 
-		@quotation
-		Permission is granted to copy, distribute, and/or modify this document
-		under the terms of the GNU Free Documentation License, Version 1.2 or
-		any later version published by the Free Software Foundation; with no
-		Invariant Sections, with the Front-Cover Texts being \`\`A Manual,''
-		and with the Back-Cover Texts as in (a) below. A copy of the
-		license is included in the section entitled \`\`GNU Free Documentation
-		License.''
+@quotation
+Permission is granted to copy, distribute, and/or modify this document
+under the terms of the GNU Free Documentation License, Version 1.2 or
+any later version published by the Free Software Foundation; with no
+Invariant Sections, with the Front-Cover Texts being \`\`A Manual,''
+and with the Back-Cover Texts as in (a) below. A copy of the
+license is included in the section entitled \`\`GNU Free Documentation
+License.''
 
-		(a) The Back-Cover Text is: \`\`You have freedom to copy and modify
-		this Manual, like GNU software.''
-		@end quotation
-		@end copying
-		@dircategory $H2I_INFO_DIRCATEGORY
-		@direntry
-		* $H2I_INFO_PROGRAM_NAME: ($H2I_INFO_PROGRAM_NAME). $H2I_INFO_DESCRIPTION
-		@end direntry
+(a) The Back-Cover Text is: \`\`You have freedom to copy and modify
+this Manual, like GNU software.''
+@end quotation
+@end copying
+@dircategory $H2I_INFO_DIRCATEGORY
+@direntry
+* $H2I_INFO_PROGRAM_NAME: ($H2I_INFO_PROGRAM_NAME). $H2I_INFO_DESCRIPTION
+@end direntry
 
-		@titlepage
-		@title $H2I_INFO_PROGRAM_NAME
-		@subtitle for version @value{VERSION}, @value{UPDATED}
-		@author $H2I_INFO_AUTHOR (@email{$H2I_INFO_BUGREPORT})
-		@page
-		@vskip 0pt plus 1filll
-		@insertcopying
-		@end titlepage
+@titlepage
+@title $H2I_INFO_PROGRAM_NAME
+@subtitle for version @value{VERSION}, @value{UPDATED}
+@author $H2I_INFO_AUTHOR (@email{$H2I_INFO_BUGREPORT})
+@page
+@vskip 0pt plus 1filll
+@insertcopying
+@end titlepage
 
-		@contents
+@contents
 
-		@ifnottex
-		@node Top
-		@top $H2I_INFO_PROGRAM_NAME
-		@insertcopying
-		@end ifnottex
+@ifnottex
+@node Top
+@top $H2I_INFO_PROGRAM_NAME
+@insertcopying
+@end ifnottex
 
-		@menu
-		* Introduction:: Introduction.
-		* Invoking $H2I_INFO_PROGRAM_NAME::	Invocation.
-		* Examples:: Some samples of use.
-		* Reporting Bugs:: Reporting bugs
-		* Copying This Manual:: The license for this documentation.
-		@end menu
+@menu
+* Introduction:: Introduction.
+* Invoking $H2I_INFO_PROGRAM_NAME::	Invocation.
+* Examples:: Some samples of use.
+* Reporting Bugs:: Reporting bugs
+* Copying This Manual:: The license for this documentation.
+@end menu
 
-		@node Introduction 
-		@chapter Introduction
-		@pindex introduction
-		@cindex introduction
-		$H2I_INFO_DESCRIPTION
+@node Introduction 
+@chapter Introduction
+@pindex introduction
+@cindex introduction
+$H2I_INFO_DESCRIPTION
 
-		@node Invoking $H2I_INFO_PROGRAM_NAME
-		@chapter Invoking $H2I_INFO_PROGRAM_NAME
-		@pindex invoking
-		@cindex invoking @command{$H2I_INFO_PROGRAM_NAME}
-		@verbatim
-		$H2I_INFO_USAGE
-		@end verbatim
+@node Invoking $H2I_INFO_PROGRAM_NAME
+@chapter Invoking $H2I_INFO_PROGRAM_NAME
+@pindex invoking
+@cindex invoking @command{$H2I_INFO_PROGRAM_NAME}
+@verbatim
+$H2I_INFO_USAGE
+@end verbatim
 
-		@command{$H2I_INFO_PROGRAM_NAME} may be invoked with the following command-line options:
+@command{$H2I_INFO_PROGRAM_NAME} may be invoked with the following command-line options:
 
-		$H2I_INFO_OPTIONS_AND_COMMENTS
+$H2I_INFO_OPTIONS_AND_COMMENTS
 
-		@node Examples
-		@chapter Examples
-		@pindex examples
-		@cindex examples
-		Insert your examples here
+@node Examples
+@chapter Examples
+@pindex examples
+@cindex examples
+Insert your examples here
 
-		@node Reporting Bugs
-		@chapter Reporting Bugs
-		@pindex bugs
-		@cindex reporting bugs
-		Email bug reports to @email{$H2I_INFO_BUGREPORT}. Be sure to include the word @dfn{$H2I_INFO_PROGRAM_NAME} somewhere in the @code{Subject:} field. Also, please include the output of @samp{$H2I_INFO_PROGRAM_NAME --version} in the body of your report if at all possible.
+@node Reporting Bugs
+@chapter Reporting Bugs
+@pindex bugs
+@cindex reporting bugs
+Email bug reports to @email{$H2I_INFO_BUGREPORT}. Be sure to include the word @dfn{$H2I_INFO_PROGRAM_NAME} somewhere in the @code{Subject:} field. Also, please include the output of @samp{$H2I_INFO_PROGRAM_NAME --version} in the body of your report if at all possible.
 
 
-		@node Copying This Manual
+@node Copying This Manual
 
-		@appendix Copying This Manual
-		@menu
-		* GNU Free Documentation License::	License for copying this manual.
-		@end menu
+@appendix Copying This Manual
+@menu
+* GNU Free Documentation License::	License for copying this manual.
+@end menu
 
-		@include fdl.texi
+@include fdl.texi
 
-		@bye
-		EOF
+@bye
+EOF
 	h2i_check_and_echo "$H2I_ERROR_LOG"
 fi
 
